
<h3 align="center">

![](img/logo.svg)

Nord
</h3>

-----------------

[Nord](https://www.nordtheme.com) is a cold, minimalist color palette that
has been applied to PlantUML.

## How to use

In order to use this theme with `mkdocs_puml`, set `theme` config of the plugin as follows:

```yml
theme:
    light: nord/light
    dark: nord/dark
```

## Flavors

This theme comes in two flavors

- `day` for light mode
- `night` for dark mode

|**nord/day**|**nord/night**|
|:-------:|:--------:|
|![](examples/classes/classes-day.svg)|![](examples/classes/classes-night.svg)|

## Examples

Below are some examples showcasing how this theme appears on various diagrams

## Sequence

|**nord/day**|**nord/night**|
|:-------:|:--------:|
|![](examples/sequence/sequence-day.svg)|![](examples/sequence/sequence-night.svg)|

### Entity Diagram

|**nord/day**|**nord/night**|
|:-------:|:--------:|
|![](examples/entity/entity-day.svg)|![](examples/entity/entity-night.svg)|

### Timing

|**nord/day**|**nord/night**|
|:-------:|:--------:|
|![](examples/timing/timing-day.svg)|![](examples/timing/timing-night.svg)|

### C4

`Nord` theme contains styling of C4 diagrams

|**nord/day**|**nord/night**|
|:-------:|:--------:|
|![](examples/c4/c4-day.svg)|![](examples/c4/c4-night.svg)|
